% method of class @signal
% function sig=generateclicktrain(sig,frequency,[amplitude])
%   INPUT VALUES:
%       sig: original @signal with length and samplerate 
%       frequency: frequency of the clicktrain (Hz)
%       amplitude: amplitude [1]
% 
%   RETURN VALUE:
%       sig:  @signal 
%
% (c) 2003-2008, University of Cambridge, Medical Research Council 
% Maintained by Tom Walters (tcw24@cam.ac.uk), written by Stefan Bleeck (stefan@bleeck.de)
% http://www.pdn.cam.ac.uk/cnbh/aim2006
% $Date: 2008-06-10 18:00:16 +0100 (Tue, 10 Jun 2008) $
% $Revision: 585 $

function sig=generateclicktrain(sig,frequency,amplitude)

if nargin < 3
    amplitude=1;
end

name= sprintf('Clicktrain %5.2f Hz',frequency);

df=floor(getsr(sig)/frequency);
to=time2bin(sig,getlength(sig));
clicks=1:df:to; % start at the sampletime

sig=setbinvalue(sig,clicks,amplitude);

